Enum icns::Encoding
[−]
[src]
pub enum Encoding {
Mask8,
RLE24,
JP2PNG,
}Methods of encoding an image within an icon element.
Each IconType uses a particular encoding within
an ICNS file; this type enumerates those encodings.
(This type is used internally by the library, but is irrelvant to most library users; if you're not sure whether you need to use it, you probably don't.)
Variants
Mask8 | Icon element data payload is an uncompressed 8-bit alpha mask. | |
RLE24 | Icon element data payload is an RLE-compressed 24-bit RGB image. | |
JP2PNG | Icon element data payload is a JPEG 2000 or PNG file. |