Struct icns::OSType
[−]
[src]
pub struct OSType(pub [u8; 4]);
A Macintosh OSType (also known as a ResType), used in ICNS files to identify the type of each icon element.
An OSType is a four-byte identifier used throughout Mac OS. In an ICNS
file, it indicates the type of data stored in an
IconElement data block. For example, OSType
is32 represents 24-bit color data for a 16x16 icon, while OSType s8mk
represents the 8-bit alpha mask for that same icon.
See the IconType enum for an easier-to-use
representation of icon data types.